.. automodule:: clients

Client
=============
.. autoclass:: Client
   :show-inheritance:
   :members:
   :special-members:
   :exclude-members: __truediv__

Resource
=============
.. autoclass:: Resource
   :show-inheritance:
   :members:
   :special-members:
